@@ -56,21 +56,86 @@ type SubDefaultController struct {
 	K8srecorder record.EventRecorder
 }
 
-// UpdateStatus update the component status on src.
-func (d *SubDefaultController) UpdateStatus(namespace string, status *dorisv1.ComponentStatus, labels map[string]string, replicas int32) error {
-	return d.ClassifyPodsByStatus(namespace, status, labels, replicas)
+func (d *SubDefaultController) CheckRestartTimeAndInject(dcr *dorisv1.DorisCluster, componentType dorisv1.ComponentType) bool {
+	var baseSpec *dorisv1.BaseSpec
+	var restartedAt string
+	var restartAnnotationsKey string
+	switch componentType {
+	case dorisv1.Component_FE:
+		baseSpec = &dcr.Spec.FeSpec.BaseSpec
+		restartedAt = dcr.Annotations[dorisv1.FERestartAt]
+		restartAnnotationsKey = dorisv1.FERestartAt
+	case dorisv1.Component_BE:
+		baseSpec = &dcr.Spec.BeSpec.BaseSpec
+		restartedAt = dcr.Annotations[dorisv1.BERestartAt]
+		restartAnnotationsKey = dorisv1.BERestartAt
+	default:
+		klog.Errorf("CheckRestartTimeAndInject dorisClusterName %s, namespace %s componentType %s not supported.", dcr.Name, dcr.Namespace, componentType)
+	}
+
+	if restartedAt == "" {
+		return false
+	}
+
+	// run shell: date +"%Y-%m-%dT%H:%M:%S%:z"
+	// "2024-11-21T11:08:56+08:00"
+	parseTime, err := time.Parse(time.RFC3339, restartedAt)
+	if err != nil {
+		checkErr := fmt.Errorf("CheckRestartTimeAndInject error: time format is incorrect. dorisClusterName: %s, namespace: %s, componentType %s, wrong parse 'restartedAt': %s , error: %s", dcr.Name, dcr.Namespace, componentType, restartedAt, err.Error())
+		klog.Error(checkErr.Error())
+		d.K8srecorder.Event(dcr, string(EventWarning), string(RestartTimeInvalid), checkErr.Error())
+		return false
+	}
+
+	effectiveStartTime := time.Now().Add(-10 * time.Minute)
+
+	if effectiveStartTime.After(parseTime) {
+		klog.Errorf("CheckRestartTimeAndInject The time has expired, dorisClusterName: %s, namespace: %s, componentType %s, wrong parse 'restartedAt': %s : The time has expired, if you want to restart doris, please set a future time", dcr.Name, dcr.Namespace, componentType, restartedAt)
+		d.K8srecorder.Event(dcr, string(EventWarning), string(RestartTimeInvalid), fmt.Sprintf("the %s restart time is not effective. the 'restartedAt' %s can't be earlier than 10 minutes before the current time", componentType, restartedAt))
+		return false
+	}
+
+	// check passed, set annotations to doriscluster baseSpec
+	if baseSpec.Annotations == nil {
+		baseSpec.Annotations = make(map[string]string)
+	}
+	baseSpec.Annotations[restartAnnotationsKey] = restartedAt
+	return true
 }
 
-func (d *SubDefaultController) ClassifyPodsByStatus(namespace string, status *dorisv1.ComponentStatus, labels map[string]string, replicas int32) error {
+// UpdateStatus update the component status on src.
+func (d *SubDefaultController) UpdateStatus(namespace string, status *dorisv1.ComponentStatus, labels map[string]string, replicas int32, componentType dorisv1.ComponentType) error {
+	return d.ClassifyPodsByStatus(namespace, status, labels, replicas, componentType)
+}
+
+func (d *SubDefaultController) ClassifyPodsByStatus(namespace string, status *dorisv1.ComponentStatus, labels map[string]string, replicas int32, componentType dorisv1.ComponentType) error {
 	var podList corev1.PodList
 	if err := d.K8sclient.List(context.Background(), &podList, client.InNamespace(namespace), client.MatchingLabels(labels)); err != nil {
 		return err
 	}
 
 	var creatings, readys, faileds []string
+	var firstRestartAnnotation, restartAnnotationsKey string
 	podmap := make(map[string]corev1.Pod)
+
+	if len(podList.Items) == 0 {
+		return nil
+	}
+
+	switch componentType {
+	case dorisv1.Component_FE:
+		restartAnnotationsKey = dorisv1.FERestartAt
+	case dorisv1.Component_BE:
+		restartAnnotationsKey = dorisv1.BERestartAt
+	}
+	firstRestartAnnotation = podList.Items[0].Annotations[restartAnnotationsKey]
+
 	//get all pod status that controlled by st.
+	stsRollingRestartAnnotationsSameCheck := true
 	for _, pod := range podList.Items {
+		if pod.Annotations[restartAnnotationsKey] != firstRestartAnnotation {
+			stsRollingRestartAnnotationsSameCheck = false
+		}
 		podmap[pod.Name] = pod
 		if ready := k8s.PodIsReady(&pod.Status); ready {
 			readys = append(readys, pod.Name)
@@ -81,7 +146,7 @@ func (d *SubDefaultController) ClassifyPodsByStatus(namespace string, status *do
 		}
 	}
 
-	if len(readys) == int(replicas) {
+	if len(readys) == int(replicas) && stsRollingRestartAnnotationsSameCheck {
 		status.ComponentCondition.Phase = dorisv1.Available
 	} else if len(faileds) != 0 {
 		status.ComponentCondition.Phase = dorisv1.HaveMemberFailed
